@@ -36,7 +36,7 @@ then
 end
 
 local _M = new_tab(0, 13)
-_M._VERSION = '0.06'
+_M._VERSION = '0.08'
 
 
 local mt = { __index = _M }
@@ -98,7 +98,7 @@ function _M.connect(self, uri, opts)
         path = "/"
     end
 
-    local ssl_verify, proto_header, origin_header, sock_opts = false
+    local ssl_verify, headers, proto_header, origin_header, sock_opts = false
 
     if opts then
         local protos = opts.protocols
@@ -128,6 +128,13 @@ function _M.connect(self, uri, opts)
             end
             ssl_verify = true
         end
+
+        if opts.headers then
+            headers = opts.headers
+            if type(headers) ~= "table" then
+                return nil, "custom headers must be a table"
+            end
+        end
     end
 
     local ok, err
@@ -152,7 +159,7 @@ function _M.connect(self, uri, opts)
 
     -- check for connections from pool:
 
-    local count,err = sock:getreusedtimes()
+    local count, err = sock:getreusedtimes()
     if not count then
         return nil, "failed to get reused times: " .. err
     end
@@ -161,6 +168,12 @@ function _M.connect(self, uri, opts)
         return 1
     end
 
+    local custom_headers
+    if headers then
+        custom_headers = concat(headers, "\r\n")
+        custom_headers = "\r\n" .. custom_headers
+    end
+
     -- do the websocket handshake:
 
     local bytes = char(rand(256) - 1, rand(256) - 1, rand(256) - 1,
@@ -177,7 +190,9 @@ function _M.connect(self, uri, opts)
                 .. (proto_header or "")
                 .. "\r\nSec-WebSocket-Version: 13"
                 .. (origin_header or "")
-                .. "\r\nConnection: Upgrade\r\n\r\n"
+                .. "\r\nConnection: Upgrade"
+                .. (custom_headers or "")
+                .. "\r\n\r\n"
 
     local bytes, err = sock:send(req)
     if not bytes then
@@ -191,6 +206,8 @@ function _M.connect(self, uri, opts)
         return nil, "failed to receive response header: " .. err
     end
 
+    -- error("header: " .. header)
+
     -- FIXME: verify the response headers
 
     m, err = re_match(header, [[^\s*HTTP/1\.1\s+]], "jo")
